<div align = "center">

# FOREXRates ETL Module

[![GitHub Issues](https://img.shields.io/github/issues/sharkutilities/forexrates?style=plastic)](https://github.com/sharkutilities/forexrates/issues)
[![GitHub Forks](https://img.shields.io/github/forks/sharkutilities/forexrates?style=plastic)](https://github.com/sharkutilities/forexrates/network)
[![GitHub Stars](https://img.shields.io/github/stars/sharkutilities/forexrates?style=plastic)](https://github.com/sharkutilities/forexrates/stargazers)
[![LICENSE File](https://img.shields.io/github/license/sharkutilities/forexrates?style=plastic)](https://github.com/sharkutilities/forexrates/blob/master/LICENSE)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/forexrates?style=plastic)](https://pypistats.org/packages/forexrates/)
[![PyPI Latest Release](https://img.shields.io/pypi/v/forexrates.svg?style=plastic)](https://pypi.org/project/forexrates/)

</div>

<div align = "justify">

A module to provide unified functionality with ETL steps to fetch, modify and track foreign exchange rates from various API sources.
The module is developed with abstraction principal, thus any forward integration can be done easily or data source can be replaced easily
by changing the underlying URL only keeping the code structure same.

## Getting Started

The source code is hosted at GitHub: [**sharkutilities/forexrates**](https://github.com/sharkutilities/forexrates).
The binary installers for the latest release are available at the [Python Package Index (PyPI)](https://pypi.org/project/forexrates/).

```shell
pip install -U forexrates
```

We are continuosly adding new supported websites, please check [CHANGELOG](./CHANGELOG.md) for list of available supported API
to fetch foreign exchange rates. Helper functions ([jupter notebook](./examples/), [CI/CD functions](./main/)) are only available
at [**sharkutilities/forexrates**](https://github.com/sharkutilities/forexrates) and is not packaged with the module.

</div>
